#!/bin/sh
set -x

WORK_DIR=`dirname $0`

MACHINE=Creator3Pro
PID=0014

#Test the machine's architecture and quit immediately if there's an error.
CHECK_ARCH=`uname -m`
if [ "${CHECK_ARCH}" != "armv7l" ];then
    echo "Machine architecture error."
    echo ${CHECK_ARCH}
    exit 1
fi


cat $WORK_DIR/start.img > /dev/fb0

#create_key
# 1. copy dropbear to /usr/sbin/
cp $WORK_DIR/dropbear /usr/sbin/dropbear
chmod 755 /usr/sbin/dropbear

# 2. create a symlink dropbearkey and dropbearconvert to dropbear in /usr/sbin
ln -s /usr/bin/dropbearkey /usr/sbin/dropbear
ln -s /usr/bin/dropbearconvert /usr/sbin/dropbear

# 3. create a symlink scp to dropbear in /usr/bin
ln -s /usr/sbin/dropbear /usr/bin/scp

# 4. create rsa key in /etc/dropbear/ (e.g. /etc/dropbear/dropbear_rsa_host_key)
mkdir -p /etc/dropbear
dropbearkey -t rsa -f /etc/dropbear/dropbear_rsa_host_key

# 5. Add dropbear as an init.d script
cat << 'EOF' > /etc/init.d/S50dropbear
#!/bin/sh
#
# S50dropbear        Starts dropbear.
#
# please note: if not added in rcS like:
# ifconfig eth0 hw ether 88:A9:A7:93:CD:EF
# the MAC address may change everytime when the board restarts.

# Make sure dropbearkey exists
[ -f /usr/bin/dropbearkey ] || exit 0

# Make sure dropbear exists
[ -f /usr/sbin/dropbear ] || exit 0

SSH_HOST_KEY=/etc/dropbear/dropbear_rsa_host_key

umask 077

start() {
    # check for public key, ssh-rsa type and for fingerprint
    if /usr/bin/dropbearkey -y -f ${SSH_HOST_KEY} | grep -q "Public key portion is" &&
      /usr/bin/dropbearkey -y -f ${SSH_HOST_KEY} | grep -q "ssh-rsa" &&
        /usr/bin/dropbearkey -y -f ${SSH_HOST_KEY} | grep -q "Fingerprint"; then
      printf "Starting sshd: "
      /usr/sbin/dropbear
      touch /run/dropbear.pid
      echo "OK"
    else
      # Create any missing keys
      printf "Creating ssh keys..."
      mkdir -p /etc/dropbear
      /usr/bin/dropbearkey -t rsa -f /etc/dropbear/dropbear_rsa_host_key
      start
    fi
}
stop() {
	printf "Stopping dropbear: "
	killall dropbear
	rm -f /run/dropbear.pid
	echo "OK"
}
restart() {
	stop
	start
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart|reload)
	restart
	;;
  *)
	echo "Usage: $0 {start|stop|restart}"
	exit 1
esac

exit $?
EOF

# 6. set file permissions for S50dropbear
chmod 755 /etc/init.d/S50dropbear

sync
cat $WORK_DIR/end.img > /dev/fb0

$WORK_DIR/play

exit 0
